@@ -74,7 +74,10 @@ class MongoEngineConnectionDatastore(MongoEngineDatastore, ConnectionDatastore):
         ConnectionDatastore.__init__(self, connection_model)
 
     def _query(self, **kwargs):
-        from mongoengine.queryset import Q, QCombination
+        try:
+            from mongoengine.queryset import Q, QCombination
+        except ImportError:
+            from mongoengine.queryset.visitor import Q, QCombination
         queries = map(lambda i: Q(**{i[0]: i[1]}), kwargs.items())
         query = QCombination(QCombination.AND, queries)
         return self.connection_model.objects(query)
